0.9.9 API documentation: GLM_EXT_vector_bool1

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Typedefs
GLM_EXT_vector_bool1
Stable extensions

Exposes bvec1 vector type. More...

## Typedefs
typedef vec< 1, bool, defaultp > | bvec1
| 1 components vector of boolean.

## Detailed Description

Exposes bvec1 vector type.

Include <glm/ext/vector_bool1.hpp> to use the features of this extension.

See also
  GLM_EXT_vector_bool1_precision extension.